==> apache-servicecomb-java-chassis-distribution-2.0.0-src.zip: apache-servicecomb-java-chassis-distribution-2.0.0-src/core/src/main/java/org/apache/servicecomb/core/definition/MicroserviceConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.core.definition;

import org.apache.servicecomb.config.inject.InjectProperties;
import org.apache.servicecomb.config.inject.InjectProperty;
import org.apache.servicecomb.serviceregistry.version.VersionRuleUtils;

@InjectProperties(prefix = "servicecomb")
public class MicroserviceConfig {
  @InjectProperty(keys = {
      "servicecomb.references.version-rule.${service}",
      "servicecomb.references.${service}.version-rule", // Deprecated
      "servicecomb.references.version-rule"
  }, defaultValue = "0.0.0.0+")
  private String versionRule;

  public String getVersionRule() {
    return versionRule;
  }

  public void setVersionRule(String versionRule) {
    this.versionRule = VersionRuleUtils.getOrCreate(versionRule).getVersionRule();
  }
}

==> apache-servicecomb-java-chassis-distribution-2.1.1-src.zip: apache-servicecomb-java-chassis-distribution-2.1.1-src/core/src/main/java/org/apache/servicecomb/core/definition/MicroserviceConfig.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.core.definition;

import org.apache.servicecomb.config.inject.InjectProperties;
import org.apache.servicecomb.config.inject.InjectProperty;
import org.apache.servicecomb.registry.version.VersionRuleUtils;

@InjectProperties(prefix = "servicecomb")
public class MicroserviceConfig {
  @InjectProperty(keys = {
      "servicecomb.references.version-rule.${service}",
      "servicecomb.references.${service}.version-rule", // Deprecated
      "servicecomb.references.version-rule"
  }, defaultValue = "0.0.0.0+")
  private String versionRule;

  public String getVersionRule() {
    return versionRule;
  }

  public void setVersionRule(String versionRule) {
    this.versionRule = VersionRuleUtils.getOrCreate(versionRule).getVersionRule();
  }
}
